@@ -2,6 +2,7 @@
  *  Copyright (c) Microsoft Corporation. All rights reserved.
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
+import { Color } from '../../../base/common/color.js';
 import { Range } from '../../common/core/range.js';
 import { Token, TokenizationResult, TokenizationResult2 } from '../../common/core/token.js';
 import * as modes from '../../common/modes.js';
@@ -52,22 +53,26 @@ export function setLanguageConfiguration(languageId, configuration) {
     if (!languageIdentifier) {
         throw new Error(`Cannot set configuration for unknown language ${languageId}`);
     }
-    return LanguageConfigurationRegistry.register(languageIdentifier, configuration);
+    return LanguageConfigurationRegistry.register(languageIdentifier, configuration, 100);
 }
 /**
  * @internal
  */
 export class EncodedTokenizationSupport2Adapter {
-    constructor(actual) {
+    constructor(languageIdentifier, actual) {
+        this._languageIdentifier = languageIdentifier;
         this._actual = actual;
     }
     getInitialState() {
         return this._actual.getInitialState();
     }
-    tokenize(line, state, offsetDelta) {
+    tokenize(line, hasEOL, state, offsetDelta) {
+        if (typeof this._actual.tokenize === 'function') {
+            return TokenizationSupport2Adapter.adaptTokenize(this._languageIdentifier.language, this._actual, line, state, offsetDelta);
+        }
         throw new Error('Not supported!');
     }
-    tokenize2(line, state) {
+    tokenize2(line, hasEOL, state) {
         let result = this._actual.tokenizeEncoded(line, state);
         return new TokenizationResult2(result.tokens, result.endState);
     }
@@ -84,7 +89,7 @@ export class TokenizationSupport2Adapter {
     getInitialState() {
         return this._actual.getInitialState();
     }
-    _toClassicTokens(tokens, language, offsetDelta) {
+    static _toClassicTokens(tokens, language, offsetDelta) {
         let result = [];
         let previousStartIndex = 0;
         for (let i = 0, len = tokens.length; i < len; i++) {
@@ -104,9 +109,9 @@ export class TokenizationSupport2Adapter {
         }
         return result;
     }
-    tokenize(line, state, offsetDelta) {
-        let actualResult = this._actual.tokenize(line, state);
-        let tokens = this._toClassicTokens(actualResult.tokens, this._languageIdentifier.language, offsetDelta);
+    static adaptTokenize(language, actual, line, state, offsetDelta) {
+        let actualResult = actual.tokenize(line, state);
+        let tokens = TokenizationSupport2Adapter._toClassicTokens(actualResult.tokens, language, offsetDelta);
         let endState;
         // try to save an object if possible
         if (actualResult.endState.equals(state)) {
@@ -117,6 +122,9 @@ export class TokenizationSupport2Adapter {
         }
         return new TokenizationResult(tokens, endState);
     }
+    tokenize(line, hasEOL, state, offsetDelta) {
+        return TokenizationSupport2Adapter.adaptTokenize(this._languageIdentifier.language, this._actual, line, state, offsetDelta);
+    }
     _toBinaryTokens(tokens, offsetDelta) {
         const languageId = this._languageIdentifier.id;
         const tokenTheme = this._standaloneThemeService.getColorTheme().tokenTheme;
@@ -149,7 +157,7 @@ export class TokenizationSupport2Adapter {
         }
         return actualResult;
     }
-    tokenize2(line, state, offsetDelta) {
+    tokenize2(line, hasEOL, state, offsetDelta) {
         let actualResult = this._actual.tokenize(line, state);
         let tokens = this._toBinaryTokens(actualResult.tokens, offsetDelta);
         let endState;
@@ -169,6 +177,22 @@ function isEncodedTokensProvider(provider) {
 function isThenable(obj) {
     return obj && typeof obj.then === 'function';
 }
+/**
+ * Change the color map that is used for token colors.
+ * Supported formats (hex): #RRGGBB, $RRGGBBAA, #RGB, #RGBA
+ */
+export function setColorMap(colorMap) {
+    if (colorMap) {
+        const result = [null];
+        for (let i = 1, len = colorMap.length; i < len; i++) {
+            result[i] = Color.fromHex(colorMap[i]);
+        }
+        StaticServices.standaloneThemeService.get().setColorMapOverride(result);
+    }
+    else {
+        StaticServices.standaloneThemeService.get().setColorMapOverride(null);
+    }
+}
 /**
  * Set the tokens provider for a language (manual implementation).
  */
@@ -179,7 +203,7 @@ export function setTokensProvider(languageId, provider) {
     }
     const create = (provider) => {
         if (isEncodedTokensProvider(provider)) {
-            return new EncodedTokenizationSupport2Adapter(provider);
+            return new EncodedTokenizationSupport2Adapter(languageIdentifier, provider);
         }
         else {
             return new TokenizationSupport2Adapter(StaticServices.standaloneThemeService.get(), languageIdentifier, provider);
@@ -255,10 +279,10 @@ export function registerDocumentHighlightProvider(languageId, provider) {
     return modes.DocumentHighlightProviderRegistry.register(languageId, provider);
 }
 /**
- * Register an on type rename provider.
+ * Register an linked editing range provider.
  */
-export function registerOnTypeRenameProvider(languageId, provider) {
-    return modes.OnTypeRenameProviderRegistry.register(languageId, provider);
+export function registerLinkedEditingRangeProvider(languageId, provider) {
+    return modes.LinkedEditingRangeProviderRegistry.register(languageId, provider);
 }
 /**
  * Register a definition provider (used by e.g. go to definition).
@@ -363,6 +387,12 @@ export function registerDocumentSemanticTokensProvider(languageId, provider) {
 export function registerDocumentRangeSemanticTokensProvider(languageId, provider) {
     return modes.DocumentRangeSemanticTokensProviderRegistry.register(languageId, provider);
 }
+/**
+ * Register an inline completions provider.
+ */
+export function registerInlineCompletionsProvider(languageId, provider) {
+    return modes.InlineCompletionsProviderRegistry.register(languageId, provider);
+}
 /**
  * @internal
  */
@@ -374,6 +404,7 @@ export function createMonacoLanguagesAPI() {
         getEncodedLanguageId: getEncodedLanguageId,
         // provider methods
         setLanguageConfiguration: setLanguageConfiguration,
+        setColorMap: setColorMap,
         setTokensProvider: setTokensProvider,
         setMonarchTokensProvider: setMonarchTokensProvider,
         registerReferenceProvider: registerReferenceProvider,
@@ -383,7 +414,7 @@ export function createMonacoLanguagesAPI() {
         registerHoverProvider: registerHoverProvider,
         registerDocumentSymbolProvider: registerDocumentSymbolProvider,
         registerDocumentHighlightProvider: registerDocumentHighlightProvider,
-        registerOnTypeRenameProvider: registerOnTypeRenameProvider,
+        registerLinkedEditingRangeProvider: registerLinkedEditingRangeProvider,
         registerDefinitionProvider: registerDefinitionProvider,
         registerImplementationProvider: registerImplementationProvider,
         registerTypeDefinitionProvider: registerTypeDefinitionProvider,
@@ -399,6 +430,7 @@ export function createMonacoLanguagesAPI() {
         registerSelectionRangeProvider: registerSelectionRangeProvider,
         registerDocumentSemanticTokensProvider: registerDocumentSemanticTokensProvider,
         registerDocumentRangeSemanticTokensProvider: registerDocumentRangeSemanticTokensProvider,
+        registerInlineCompletionsProvider: registerInlineCompletionsProvider,
         // enums
         DocumentHighlightKind: standaloneEnums.DocumentHighlightKind,
         CompletionItemKind: standaloneEnums.CompletionItemKind,
@@ -409,6 +441,8 @@ export function createMonacoLanguagesAPI() {
         IndentAction: standaloneEnums.IndentAction,
         CompletionTriggerKind: standaloneEnums.CompletionTriggerKind,
         SignatureHelpTriggerKind: standaloneEnums.SignatureHelpTriggerKind,
+        InlayHintKind: standaloneEnums.InlayHintKind,
+        InlineCompletionTriggerKind: standaloneEnums.InlineCompletionTriggerKind,
         // classes
         FoldingRangeKind: modes.FoldingRangeKind,
     };
